@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Public link" : "Link público",
     "Photos" : "Fotos",
+    "On This Day" : "Neste dia",
     "Your memories under your control" : "Suas memórias sob seu controle",
     "All media" : "Toda mídia",
     "Videos" : "Vídeos",
@@ -48,23 +49,40 @@ OC.L10N.register(
     "Failed to update album." : "Falha ao atualizar álbum.",
     "This collection does not exist" : "Esta coleção não existe",
     "An error occurred" : "Ocorreu um erro",
+    "No picture for this day" : "Nenhuma foto para este dia",
+    "Picture taken on this day will show up here." : "A foto tirada neste dia aparecerá aqui.",
+    "More photos from this day" : "Mais fotos deste dia",
     "_%n unassigned photo_::_%n unassigned photos_" : ["%nfoto não identificada","%nfotos não identificadas","%nfotos não identificadas"],
     "Favorite" : "Favorito",
     "Select image {imageName}" : "Selecionar imagem {imageName}",
+    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abra a imagem \"{name}\" em tamanho real",
     "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
-    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
-    "Add to {destination}" : "Adicionar a {destionation}",
+    "Open the \"{name}\" folder" : "Abra a pasta \"{nome}\"",
     "Go back" : "Voltar",
     "Back to {folder}" : "Voltar para {folder}",
     "Share this folder" : "Compartilhar esta pasta",
+    "Dates" : "Datas",
+    "Jump to specific date in list" : "Ir para uma data específica na lista",
+    "Jump to {date}" : "Ir para {data}",
+    "Add to {destination}" : "Adicionar a {destination}",
+    "The destination folder is owned by {owner}" : "A pasta de destino pertence a {owner}",
+    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
     "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
     "Enable squared photos view" : "Ativar exibição de fotos quadradas",
-    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
+    "Delete source directory" : "Excluir diretório de origem",
+    "All folders" : "Todas as pastas",
+    "Add a Photos source for the timelines" : "Adicione uma fonte de fotos para os cronogramas",
+    "Add folder" : "Adicionar pasta",
+    "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
+    "Home" : "Início",
     "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
-    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
-    "Invalid location selected" : "Invalidar localização selecionada",
+    "Choose a different folder" : "Escolha uma pasta diferente",
+    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
     "View" : "Exibição",
-    "Photos directory" : "Diretório de fotos",
+    "Media folders" : "Pastas de mídia",
+    "Choose the folders from where photos and videos are shown." : "Escolha as pastas onde as fotos e vídeos serão mostrados.",
+    "Upload folder" : "Carregar pasta",
+    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta para onde as fotos e os álbuns serão carregados.",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "Unselect all" : "Desmarque todos",
     "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
@@ -109,6 +127,8 @@ OC.L10N.register(
     "No tags yet" : "Ainda não há marcações",
     "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
     "Popular tags" : "Etiquetas populares",
+    "All tags" : "Todas as etiquetas",
+    "One of the source folders does not exist" : "Um dos arquivos da fonte não existe",
     "Add" : "Adicionar",
     "Add to album" : "Adicionar a álbum",
     "Delete selection" : "Excluir seleção",
@@ -134,23 +154,11 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
     "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
     "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
-    "Go back to the previous view." : "Ir para a visualização anterior.",
-    "Go to the add collaborators view." : "Ir para visualização de adicionar colaboradores.",
-    "Create the album." : "Criar o álbum.",
-    "Back to the new album form." : "Voltar ao formulário de novo álbum.",
-    "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
-    "Search for collaborators" : "Pesquisar colaboradores",
-    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
-    "No collaborators available" : "Nenhum colaborador disponível",
-    "Failed to fetch album." : "Falha ao buscar álbum.",
-    "The file is in the favorites" : "Esse arquivo está nos favoritos",
-    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
-    "Add photos to the album" : "Adicionar fotos ao álbum",
-    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
-    "Shared albums" : "Álbuns compartilhados",
-    "Create a new album" : "Criar um novo álbum",
-    "Add selection to an album" : "Adicionar seleção a um álbu",
-    "Failed to create {albumName}." : "Falha ao criar {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}."
+    "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
+    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
+    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
+    "Invalid location selected" : "Invalidar localização selecionada",
+    "Photos directory" : "Diretório de fotos",
+    "One of the source folders does not exists" : "Uma das pastas de origem não existe"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
