@@ -14,7 +14,7 @@ OC.L10N.register(
     "Click the following button to confirm your email." : "إضغط الزر التالي لتأكيد الإيميل",
     "Click the following link to confirm your email." : "إضغط الرابط التالي لتأكيد الإيميل",
     "Confirm your email" : "قم بتأكيد إيميلك",
-    "Other activities" : "حركات أخرى",
+    "Other activities" : "أنشطة أخرى",
     "%1$s and %2$s" : "%1$s و %2$s",
     "%1$s, %2$s and %3$s" : "%1$s، %2$s و %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s و %4$s",
@@ -37,10 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "المنصّات التالية مدعومة: %s",
     "Server version %s or higher is required." : "مطلوب إصدار الخادم %s أو أعلى.",
     "Server version %s or lower is required." : "مطلوب إصدار الخادم %s أو أقل.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
-    "Your current IP address doesn’t allow you to perform admin actions" : "عنوانك الحالي IP يمنعك من أداء مهام المشرف",
-    "Logged in account must be an admin or sub admin" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً ",
-    "Logged in account must be an admin" : "الداخل للحساب يجب أن يكون مُشرفاً ",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الحساب المسجل دخوله يجب أن يكون حساب مدير أو مدير فرعي أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
+    "Your current IP address doesn’t allow you to perform admin actions" : "عنوانك الحالي IP يمنعك من أداء مهام المدير",
+    "Logged in account must be an admin or sub admin" : "الحساب المسجل دخوله يجب أن يكون حساب مدير أو مدير فرعي",
+    "Logged in account must be an admin" : "الحساب المسجل دخوله يجب أن يكون حساب مدير",
     "Wiping of device %s has started" : "بدأ مسح الجهاز %s ",
     "Wiping of device »%s« has started" : "بدأ مسح الجهاز »%s« ",
     "»%s« started remote wipe" : "»%s« بدأ المسح عن بُعدٍ",
@@ -77,10 +77,10 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n منذ ساعات","%n منذ ساعة","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات"],
     "_in %n minute_::_in %n minutes_" : ["في %nدقائق","في %nدقيقة","في %nدقائق","في %nدقائق","في %nدقائق","في %nدقائق"],
     "_%n minute ago_::_%n minutes ago_" : ["%n منذ دقائق","%n منذ دقيقة","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق"],
-    "in a few seconds" : "خلال بضع ثواني",
-    "seconds ago" : "منذ ثواني",
+    "in a few seconds" : "خلال بضع ثوانٍ",
+    "seconds ago" : "منذ ثوانٍ",
     "Empty file" : "ملفٌ فارغٌ",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "الوحدة module ذات الرقم ID ـ : %s غير موجودة. رجاءً، فعّلها في إعدادات التطبيقات لديك، أو اتصل بمشرف نظامك.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "الوحدة module ذات الرقم ID ـ : %s غير موجودة. رجاءً، فعّلها في إعدادات التطبيقات لديك، أو اتصل بمسؤول النظام.",
     "Dot files are not allowed" : "الملفات النقطية (ملفات ذات أسماء تبدأ بنقطة) غير مسموح بها",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" غير مسموح به أن يكون اسم ملف أو مجلد.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" غير مسموح به أن يكون بادئة لاسم ملف أو مجلد.",
@@ -92,6 +92,13 @@ OC.L10N.register(
     "Invalid path" : "مسار غير صالح !",
     "Failed to create file from template" : "تعذّر إنشاء ملفٍ من قالبٍ",
     "Templates" : "القوالب",
+    "Storage %s cannot be moved" : "وحدة التخزين %s لايمكن نقلها",
+    "Moving a share (%s) into a shared folder is not allowed" : "نقل مشاركة (%s) في مجلد مشترك غير ممكن",
+    "Moving a storage (%s) into a shared folder is not allowed" : "نقل وحدة تخزين (%s) في مجلد مشترك غير ممكن",
+    "Moving a share (%s) into another share (%s) is not allowed" : "نقل مشاركة (%s) في مشاركة أخرى (%s) غير ممكن",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "نقل مشاركة (%s) لوحدة تخزين أخرى (%s) غير ممكن",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "نقل وحدة تخزين (%s) في مشاركة (%s) غير ممكن",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "نقل وحدة تخزين (%s) في وحدة تخزين أخرى (%s) غير ممكن",
     "Path contains invalid segments" : "يحتوي المسار على أجزاء غير صحيحة",
     "Filename is a reserved word" : "اسم الملف غير مقبوله لأنه كلمة محجوزة",
     "Filename contains at least one invalid character" : "اسم الملف به على الأقل حرفٌ غير صالح",
@@ -104,7 +111,7 @@ OC.L10N.register(
     "Help & privacy" : "المساعدة والخصوصية",
     "Appearance and accessibility" : "المظهر وسهولة الوصول",
     "Apps" : "التطبيقات",
-    "Personal settings" : "إعدادات شخصيّة",
+    "Personal settings" : "إعدادات شخصية",
     "Administration settings" : "إعدادات الإدارة",
     "Settings" : "الإعدادات",
     "Log out" : "الخروج",
@@ -125,7 +132,7 @@ OC.L10N.register(
     "Display name" : "اسم العرض",
     "Headline" : "عنوان ",
     "Organisation" : "مؤسسة",
-    "Role" : "الدور",
+    "Role" : "الوظيفة",
     "Pronouns" : "الضمائر",
     "Unknown account" : "حساب غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
@@ -142,20 +149,18 @@ OC.L10N.register(
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "يبدو أن كائن %s يعمل على بيئة PHP 32-Bit  وكذلك تم تكوين open_basedir في ملف php.ini. يؤدي ذلك إلى مشاكل مع الملفات التي يزيد حجمها عن 4 غيغابايت ولا يُنصح بذلك بشدة.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
-    "Set an admin Login." : "تعيين مُعرف تسجيل دخول المشرف.",
-    "Set an admin password." : "تعيين كلمة مرور للمشرف",
+    "Set an admin Login." : "تعيين مُعرف تسجيل دخول المدير.",
+    "Set an admin password." : "تعيين كلمة مرور للمدير",
     "Cannot create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في دليل البيانات %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "يجب أن تقوم الواجهة الخلفية للمشاركة (Sharing backend) %s بتطبيق الواجهة OCP\\Share_Backend",
     "Sharing backend %s not found" : "لم يتم العثور على الواجهة الخلفية (Sharing backend)  %s",
     "Sharing backend for %s not found" : "مشاركة الخلفية لـ %s غير موجود",
-    "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
-    "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
-    "Click the button below to open it." : "اضغط على الزر الذي تحته ليتم فتحه.",
-    "Open »%s«" : "فتح »%s«",
+    "%1$s shared %2$s with you" : "قام%1$s بمشاركة %2$s معك",
+    "Open %s" : "إفتَح %s",
     "%1$s via %2$s" : "%1$s عبر %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s شارك »%2$s« معك و يرغب في إضافة:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s شارك »%2$s« معك و يرغب في إضافة",
-    "»%s« added a note to a file shared with you" : "»%s« أضاف ملاحظة لملفٍ سلفت مشاركته معك",
+    "%1$s shared %2$s with you and wants to add:" : "قام %1$s بمشاركة %2$s معك، وهو يرغب في إضافة:",
+    "%1$s shared %2$s with you and wants to add" : "قام%1$s بمشاركة %2$s معك، وهو يرغب في إضافة",
+    "%s added a note to a file shared with you" : "فام%s بإضافة ملاحظة إلى ملف سبقت مشاركته معك",
     "Passwords are enforced for link and mail shares" : "كلمة المرور مطلوبة للمشاركات عن طريق الروابط و البريد الإلكتروني",
     "Share recipient is not a valid user" : "مُستلِم المشاركة ليس مستخدِماً صالحاً",
     "Share recipient is not a valid group" : "مُستلِم المشاركة ليس مجموعةً صالحةً",
@@ -266,7 +271,7 @@ OC.L10N.register(
     "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "لا توجد برامج تشغيل لقاعدة البيانات (sqlite أو mysql أو postgresql) مثبتة.",
     "Cannot write into \"config\" directory." : "تعذّرت الكتابة في الدليل 'config\".",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادم الوب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادم الويب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "و إذا كنت تُفضّل بقاء الملف \"config.php\" للقراءة فقط، عيّن الخيار  \"config_is_read_only\". أنظر: %s",
     "Cannot write into \"apps\" directory." : "لا يمكن الكتابة في الدليل \"apps\".",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات في الملف او تعطيل متجر تطبيقات ابل في ملف \"config\".",
@@ -287,7 +292,7 @@ OC.L10N.register(
     "PHP modules have been installed, but they are still listed as missing?" : "تم تثبيت وحدات PHP ، لكنها لا تزال مدرجة على أنها وحدات مفقودة؟",
     "Please ask your server administrator to restart the web server." : "يرجى مطالبة مسؤول الخادم بإعادة تشغيل خادم الويب.",
     "The required %s config variable is not configured in the config.php file." : "مُتغيّر التهيئة %s المطلوب لم تتم تهيئته في الملف config.php.",
-    "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مشرف نظامك مراجعة تهيئة نكست كلاود Nextcloud configuration.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مسؤول النظام مراجعة تهيئة نكست كلاود.",
     "Your data directory is readable by other people." : "دليل بياناتك مسموحٌ بقراءته من قِبَل أشخاص آخرين.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "قُم رجاءً بتغيير الأذونات إلى 0770 حتى لا يتسنّى لأشخاص آخرين استعراض الدليل.",
     "Your data directory must be an absolute path." : "مسار دليل بياناتك data directory يجب أن يكون مساراً مُطلقاً absolute path.",
@@ -298,7 +303,7 @@ OC.L10N.register(
     "Authentication failed, wrong token or provider ID given" : "فشلت المصادقة بسبب خطأ في الرمز token أو في رقم المُزوّد provider ID المُعطى.",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "المعاملات المطلوبة لإكمال الطلب مفقودةٌ. المعاملات المطلوبة هي: \"%s\"",
     "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : " المُعّرف \"%1$s\" مٌستخدمٌ سلفاُ من مُزوّد اتحاد سحابي cloud fereration provider \"%2$s\"",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "لا يوجد مُزوّد اتحاد سحابي Cloud Federation Provider بهذا الاسم: \"%s\" .",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "لا يوجد مزود للسحابة الموحدة بهذا الاسم: \"%s\" .",
     "Could not obtain lock type %d on \"%s\"." : "تعذر الحصول على نوع القفل%d على \"%s\".",
     "Storage unauthorized. %s" : "التخزين غير مصرح به.%s",
     "Storage incomplete configuration. %s" : "تكوين التخزين غير مكتمل. %s",
@@ -312,6 +317,20 @@ OC.L10N.register(
     "The audio to transcribe" : "الكلام المطلوب تحويله إلى نص",
     "Transcription" : "تحويل الكلام لنص",
     "The transcribed text" : "النص المُولّد من الكلام",
+    "ContextAgent" : "وكيل السياق ContextAgent",
+    "Chat with an agent" : "الدردشة مع وكيل",
+    "Chat message" : "رسالة دردشة",
+    "A chat message to send to the agent." : "رسالة دردشة لتُرسل إلى الوكيل.",
+    "Confirmation" : "تأكيد",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "ما إذا كان سيتم تأكيد الإجراءات المطلوبة مسبقًا: 0 للرفض و 1 للتأكيد.",
+    "Conversation token" : "أَمَارَة المحادثة",
+    "A token representing the conversation." : "أَمَارَة تُمثّل المحادثة",
+    "Generated response" : "الاستجابة الناتجة",
+    "The response from the chat model." : "الجواب من نموذج المحادثة.",
+    "The new conversation token" : "أَمَارَة المحادثة الجديدة",
+    "Send this along with the next interaction." : "أرسل هذا مع التفاعل القادم.",
+    "Requested actions by the agent" : "إجراءات يطلبها الوكيل",
+    "Actions that the agent would like to carry out in JSON format." : "الإجراءات التي يرغب العميل في تنفيذها بتنسيق JSON.",
     "Context write" : "كتابة السياق",
     "Writes text in a given style based on the provided source material." : "يكتُب النص أسلوب معين بناءً على المادة المصدرية المتوفرة",
     "Writing style" : "أسلُوب الكتابة",
@@ -338,15 +357,29 @@ OC.L10N.register(
     "Describe a task that you want the assistant to do or ask a question" : "صِف المهمة التي تطلب العون لإنجازها أو اسأل سؤالاً",
     "Generated reply" : "الرَّدّ المُولَّد",
     "The generated text from the assistant" : "النص المُولَّد من قِبَل المُساعِد",
+    "Change Tone" : "تغيير النغمة",
+    "Change the tone of a piece of text." : "تغيير نبرة قطعة نصية.",
+    "Write a text that you want the assistant to rewrite in another tone." : "أكتُب النص الذي تريد من المساعد أن يعيد صياغته لك بنغمة مختلفة.",
+    "Desired tone" : "النغمة المطلوبة",
+    "In which tone should your text be rewritten?" : "بأي نغمة تريد إعادة صياغة نصك؟",
+    "The rewritten text in the desired tone, written by the assistant:" : "النص المعاد صياغته من قِبَل \"المساعد\" بحسب النغمة المطلوبة:",
     "Chat" : "دردشة",
     "Chat with the assistant" : "دردشة مع المُساعِد",
     "System prompt" : "مَحَثُّ النظام",
     "Define rules and assumptions that the assistant should follow during the conversation." : "تعريف القواعد و الافتراضات التي يجب على المساعد اتِّباعها خلال المحادثة.",
-    "Chat message" : "رسالة دردشة",
     "Chat history" : "تاريخ الدردشة",
     "The history of chat messages before the current message, starting with a message by the user" : "تاريخ رسائل الدردشة ما قبل الرسالة الحالية بدءاً برسالة من المستخدِم",
     "Response message" : "رسالة الرّدّ",
     "The generated response as part of the conversation" : "الرَّدّ المُولّد كجزء من المحادثة",
+    "Chat with tools" : "الدردشة مع الأدوات",
+    "Chat with the language model with tool calling support." : "الدردشة مع النموذج اللغوي باستعمال دعم استدعاء الأداوات.",
+    "Tool message" : "رسالة الأداة",
+    "The result of tool calls in the last interaction" : "نتيجة استدعاءات الأدوات في التفاعل الأخير",
+    "Available tools" : "الأدوات المتوفرة",
+    "The available tools in JSON format" : "الأدوات المتوفرة في تنسيق JSON",
+    "The response from the chat model" : "الجواب من نموذج الدردشة",
+    "Tool calls" : "مكالمات الأدوات",
+    "Tools call instructions from the model in JSON format" : "تعليمات استدعاء الأدوات من النموذج بتنسيق JSON",
     "Formalize text" : "إضفاء الطابع الرسمي على النّصّ",
     "Takes a text and makes it sound more formal" : "يأخذ النص و يجعله يبدو أكثر رسميّةً",
     "Write a text that you want the assistant to formalize" : "أكتُب النّصّ الذي ترغب من المساعد أن يجعله رسميّاً",
@@ -357,6 +390,12 @@ OC.L10N.register(
     "Original text" : "النص الأصلي",
     "The original text to generate a headline for" : "النص الأصلي المطلوب توليد عنوانٍ له",
     "The generated headline" : "العنوان الذي تم توليده",
+    "Proofread" : "مراجعة",
+    "Proofreads a text and lists corrections" : "يراجع نصاً و يعرض التصحيحات",
+    "Text" : "نص",
+    "The text to proofread" : "النص المطلوب مراجعته",
+    "Corrections" : "التصحيحات",
+    "The corrections that should be made in your text" : "التصحيحات المطلوبة في نصك",
     "Reformulate text" : "إعادة صياغة النص",
     "Takes a text and reformulates it" : "تأخذ النص و تضفي عليه طابعاً رسميّاً",
     "Write a text that you want the assistant to reformulate" : "أكتُب النص الذي ترغب من المساعد أن يعيد صياغته",
@@ -393,9 +432,9 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "يُلَخِّص النص بتقليل طوله دون فقدان المعنى.",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
     "Education Edition" : "الإصدار التعليمي",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
-    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
-    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم المسجل دخوله يجب أن يكون مدير admin، أو مدير فرعي sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
+    "Logged in user must be an admin or sub admin" : "المستخدم المسجل دخوله يجب أن يكون مدير admin، أو مدير فرعي sub",
+    "Logged in user must be an admin" : "المستخدم المسجل دخوله يجب أن يكون مدير admin.",
     "File name is a reserved word" : "اسم الملف كلمة محجوزة",
     "File name contains at least one invalid character" : "اسم الملف به ، على الأقل ، حرف غير صالح",
     "File name is too long" : "اسم الملف طويل جداً",
@@ -407,13 +446,20 @@ OC.L10N.register(
     "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
     "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
     "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
-    "Set an admin username." : "اعداد اسم مستخدم المشرف",
+    "Set an admin username." : "اعداد اسم مستخدم المدير",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s شارك »%2$s« معك و يرغب في إضافة:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s شارك »%2$s« معك و يرغب في إضافة",
+    "»%s« added a note to a file shared with you" : "»%s« أضاف ملاحظة لملفٍ سلفت مشاركته معك",
+    "Open »%s«" : "فتح »%s«",
     "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
+    "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
+    "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
+    "Click the button below to open it." : "اضغط على الزر الذي تحته ليتم فتحه.",
     "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
     "Could not create user" : "لا يمكن إنشاء المستخدم",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
     "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
-    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
+    "Username contains whitespace at the beginning or at the end" : "إنّ اسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
     "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
     "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
     "User disabled" : "تم تعطيل المستخدم",
